summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMartin Schlemmer <azarah@gentoo.org>2002-04-22 20:51:46 +0000
committerMartin Schlemmer <azarah@gentoo.org>2002-04-22 20:51:46 +0000
commite4ceb990eca04755af69eaeeb63a2cf6cd3696ca (patch)
tree8f5e804e22004d390766a260cc24fe93e5c44b67 /sys-devel/autoconf
parent- Initial version of the ebuild. (diff)
downloadgentoo-2-e4ceb990eca04755af69eaeeb63a2cf6cd3696ca.tar.gz
gentoo-2-e4ceb990eca04755af69eaeeb63a2cf6cd3696ca.tar.bz2
gentoo-2-e4ceb990eca04755af69eaeeb63a2cf6cd3696ca.zip
fix ac-wrapper.pl
Diffstat (limited to 'sys-devel/autoconf')
-rw-r--r--sys-devel/autoconf/ChangeLog8
-rw-r--r--sys-devel/autoconf/files/ac-wrapper.pl8
2 files changed, 10 insertions, 6 deletions
diff --git a/sys-devel/autoconf/ChangeLog b/sys-devel/autoconf/ChangeLog
index 30263c170254..fd965090e7c6 100644
--- a/sys-devel/autoconf/ChangeLog
+++ b/sys-devel/autoconf/ChangeLog
@@ -1,10 +1,14 @@
# ChangeLog for sys-devel/autoconf
# Copyright 2002 Gentoo Technologies, Inc.; Distributed under the GPL
-# $Header: /var/cvsroot/gentoo-x86/sys-devel/autoconf/ChangeLog,v 1.3 2002/04/07 06:35:07 azarah Exp $
+# $Header: /var/cvsroot/gentoo-x86/sys-devel/autoconf/ChangeLog,v 1.4 2002/04/22 20:51:45 azarah Exp $
+
+ 22 April 2002; M.Schlemmer <azarah@gentoo.org> ac-wrapper.pl :
+
+ Update so that it can work with AC_PREREQ([2.13]) as well as AC_PREREQ(2.13).
autoconf-1.52d-r1 (21 March 2002)
-7 April 2002; M.Schlemmer <azarah@gentoo.org> :
+ 7 April 2002; M.Schlemmer <azarah@gentoo.org> :
Change the names of the 2.5x binaries to foo-${PV}, since they do support
limited parallel versions, and foo-2.5x breaks recursion if they call
diff --git a/sys-devel/autoconf/files/ac-wrapper.pl b/sys-devel/autoconf/files/ac-wrapper.pl
index b0235ce96983..2f20ed7494dd 100644
--- a/sys-devel/autoconf/files/ac-wrapper.pl
+++ b/sys-devel/autoconf/files/ac-wrapper.pl
@@ -16,7 +16,7 @@
# Executes the correct autoconf version.
#
# - defaults to autoconf-2.13
# - runs autoconf-2.5x if it exists and...
# - envvar WANT_AUTOCONF_2_5 is set to `1'
# -or-
# - configure.ac is present
@@ -30,14 +30,14 @@
sub cat_ { local *F; open F, $_[0] or return; my @l = <F>; wantarray ? @l : join '', @l }
my $binary = "$0-2.13";
-my $binary_new = "$0-2.5x";
+my $binary_new = "$0-2.52d";
if (!$ENV{WANT_AUTOCONF_2_1}) {
if (-x $binary_new # user may have only 2.13
&& ($ENV{WANT_AUTOCONF_2_5}
|| -r 'configure.ac'
- || (cat_('configure.in') =~ /^\s*AC_PREREQ\(([^\)]{3})[^\)]*\)/m ? $1 : '') gt '2.1'
- || (cat_('aclocal.m4') =~ /^\s*AC_PREREQ\(([^\)]{3})[^\)]*\)/m ? $1 : '') gt '2.1')) {
+ || (cat_('configure.in') =~ /^\s*AC_PREREQ\(\[?([^\)]{3})[^\)]*\)/m ? $1 : '') gt '2.1'
+ || (cat_('aclocal.m4') =~ /^\s*AC_PREREQ\(\[?([^\)]{3})[^\)]*\)/m ? $1 : '') gt '2.1')) {
$ENV{WANT_AUTOCONF_2_5} = 1; # to prevent further "cats" and to enhance consistency (possible cwd etc)
$binary = $binary_new;
} else {
@@ -16,7 +16,7 @@
#
# - defaults to autoconf-2.13
-# - runs autoconf-2.5x if it exists and...
+# - runs autoconf-2.52d if it exists and...
# - envvar WANT_AUTOCONF_2_5 is set to `1'
# -or-